Description: Pychemkin HTML Report.

# Pychemkin Report

# Reaction System

Temperature: $temperature$K

Reaction | Forward Reaction Coeff. (kf) | Backward Reaction Coeff. (kb)
--- | --- | ---
$reaction_system$

# Reaction system concentrations

Specie | Initial Concentration | Final Concentration
--- | --- | ---
$conc_string$

$is_equilibrium$

# Visualization

## Reaction Time Series

## Reaction Network

This diagram shows how species in the reaction system relate to one another. The size of the annulus around the species name scales linearly with the concentration of the species at a given timepoint. Red bubbles indicate that the concentration is decreasing and teal bubbles indicate that the concentration is increasing. Species that react with one another (including reverse reactions) are connected by blue ribbons. The width of the ribbon is scaled by the logarithm of the reaction rate coefficient (forward coefficient for the forward reaction and backward coefficient for the backward reaction, if applicable.)